%%
clc
clear;
% close all;

addpath util
%%
nw = 3e3;
% Angular frequency the Laplace variable is evaluated at
% w = linspace(3e-3,60*2*pi,nw)';
w = linspace(1e-1,10*2*pi,nw)';
% w = linspace(1e-1,10*2*pi,nw)';

% w = logspace(-.5,2.5,nw)';
% Laplace variable
s = 1j*w;

% Run script setting physical parameters
parameters

%%
Zap  =   zeta_ap.*sqrt(1 + ka./s);
Zac  =   zeta_ac.*sqrt(1 + ka./s);
Gap  =   s.*t_ap.*sqrt(1 + ka./s);
Gac  =   s.*t_ac.*sqrt(1 + ka./s);

Ztp  =   zeta_tp.*sqrt(1 + kt./s);
Ztc  =   zeta_tc.*sqrt(1 + kt./s);
Gtp  =   s.*t_tp.*sqrt(1 + kt./s);
Gtc  =   s.*t_tc.*sqrt(1 + kt./s);

ZaLi   = zeta_ap*1e2;
ZaLm   = zeta_ap*1;
ZaL0   = zeta_ap/1e2;
ZtLi   = zeta_tp*1e2;
ZtLm   = zeta_tp*1;
ZtL0   = zeta_tp/1e2;

ga_p = zeta_ap./Zap .*(Zap+ZaLi.*tanh(Gap)) ./(ZaLi+Zap.*tanh(Gap));
ZaLc = zeta_ap./ga_p;
ga_i   = zeta_ac./Zac .*(Zac+ZaLc.*tanh(Gac)) ./(ZaLc+Zac.*tanh(Gac));

ga_p = zeta_ap./Zap .*(Zap+ZaLm.*tanh(Gap)) ./(ZaLm+Zap.*tanh(Gap));
ZaLc = zeta_ap./ga_p;
ga_m   = zeta_ac./Zac .*(Zac+ZaLc.*tanh(Gac)) ./(ZaLc+Zac.*tanh(Gac));

ga_p = zeta_ap./Zap .*(Zap+ZaL0.*tanh(Gap)) ./(ZaL0+Zap.*tanh(Gap));
ZaLc = zeta_ap./ga_p;
ga_0   = zeta_ac./Zac .*(Zac+ZaLc.*tanh(Gac)) ./(ZaLc+Zac.*tanh(Gac));

gt_p = zeta_tp./Ztp .*(Ztp+ZtLi.*tanh(Gtp)) ./(ZtLi+Ztp.*tanh(Gtp));
ZtLc = zeta_tp./gt_p;
gt_i   = zeta_tc./Ztc .*(Ztc+ZtLc.*tanh(Gtc)) ./(ZtLc+Ztc.*tanh(Gtc));

gt_p = zeta_tp./Ztp .*(Ztp+ZtLm.*tanh(Gtp)) ./(ZtLm+Ztp.*tanh(Gtp));
ZtLc = zeta_tp./gt_p;
gt_m   = zeta_tc./Ztc .*(Ztc+ZtLc.*tanh(Gtc)) ./(ZtLc+Ztc.*tanh(Gtc));

gt_p = zeta_tp./Ztp .*(Ztp+ZtL0.*tanh(Gtp)) ./(ZtL0+Ztp.*tanh(Gtp));
ZtLc = zeta_tp./gt_p;
gt_0   = zeta_tc./Ztc .*(Ztc+ZtLc.*tanh(Gtc)) ./(ZtLc+Ztc.*tanh(Gtc));

%%
delay = (1-exp(-s*tN));
Ga_i      =   ga_i      .*Ka./s.*delay;
Ga_m      =   ga_m      .*Ka./s.*delay;
Ga_0      =   ga_0      .*Ka./s.*delay;
Gt_i      =  -gt_i      .*Kt./s.*delay;
Gt_m      =  -gt_m      .*Kt./s.*delay;
Gt_0      =  -gt_0      .*Kt./s.*delay;

pp = 1/2/pi;

%%
figure(2); clf
opt.hz = 1;
opt.corphase = [1]*2*pi/tN;
opt.corphaseNEG = [];
bodelin([Ga_i],w,opt);
bodelin([Ga_m,Ga_0],w,opt);
% opt.corphase = [2*pi 4*pi]*Omega;
% bodelin([Gt_i],w,opt);
subplot(211);plot(pp*w,zeros(size(w)),':k'); grid on;
subplot(212);plot(pp*w,zeros(size(w))-180,':k'); grid on;
subplot(211);
ylim([-40 60]);
l = legend('$Z_a^L=100*Z_a^c$','$Z_a^L=Z_a^c$',...
    '$Z_a^L=1/100*Z_a^c$','location','best');
set(l,'interpreter','latex');
subplot(212)
ylim([-360 180]);

%%
figure(3); clf
opt.hz = 1;
opt.corphase = [2]*2*pi/tN;
opt.corphaseNEG = []*pi/tN;
bodelin([Gt_i],w,opt);
opt.corphase = [2]*2*pi/tN;
opt.corphaseNEG = [0];
bodelin([Gt_m],w,opt);
opt.corphase = [1]*2*pi/tN;
bodelin([Gt_0],w,opt);
% opt.corphase = [2*pi 4*pi]*Omega;
subplot(211);plot(pp*w,zeros(size(w)),':k'); grid on;
subplot(212);plot(pp*w,zeros(size(w))-180,':k'); grid on;
subplot(211);
ylim([-40 60]);
l = legend('$Z_t^L=100*Z_t^c$','$Z_t^L=Z_t^c$',...
    '$Z_t^L=1/100*Z_t^c$','location','best');
set(l,'interpreter','latex');
subplot(212)
ylim([-360-180 180]);

%%
% h = figure(1);
% pdfmatlabfrag2(h,'hh');

% h = figure(2);
% pdfmatlabfrag2(h,'gaFFF');

% h = figure(2);
% pdfmatlabfrag2(h,'Ha');

% h = figure(3);
% pdfmatlabfrag2(h,'Ht');

% h = figure(4);
% pdfmatlabfrag2(h,'gsub');

% h = figure(11);
% pdfmatlabfrag2(h,'delayPhase');

% h = figure(12);
% pdfmatlabfrag2(h,'GGG');

% pdfmatlabfrag2(h,'Ht');

% h = figure(5);
% pdfmatlabfrag2(h,'Gasub');
% h = figure(6);
% pdfmatlabfrag2(h,'Nyquist');


% h = figure(15);
% pdfmatlabfrag2(h,'bode_contributions');

% h = figure(16);
% pdfmatlabfrag2(h,'Gsub');

















