%% Physical Params
ro = 0.0635;     %[m] Drill string inner radius
ri = 0.0540;     %[m] Drill string outer radius
rco= 0.0762;     %[m] Drill collar outer radius
rci= 0.0286;     %[m] Drill collar inner radius
a =  0.108;      %[m] Bit-rock interaction law parameter
epsilon = 20e6;  %[Pa] Bit-rock interaction law parameter
zeta = 0.6;      %[-] Bit-rock interaction law parameter
N = 4;           %[-] Number of blades of the PDC bit

Ap = pi*(ro^2-ri^2);  %[m^2] Drill string cross sectional area
Jp = pi/2*(ro^4-ri^4);  %[m^4] Drill string polar moment of inertia
Ac = pi*(rco^2-rci^2)*2/1.5;  %[m^2] Drill collar cross sectional area
Jc = pi/2*(rco^4-rci^4);%[m^4] Drill collar polar moment of inertia

% Ac = Ap;
% Jc = Jp;

Lp = 1000;       %[m] Drill string length
Lc = 300;       %[m] Drill collar inner radius
L = Lp+Lc;      %[m] Total length
E = 200e9;      %[Pa] Youngs modulus
G = 77e9;       %[m] Shear modulus
rho = 8e3;      %[kg/m3] Density

ka   = .3;                      %[-] Axial domain damping
kt   = .3;                      %[-] Torsional domain damping

% omega0 = 90/60*2*pi;   %[rad/s] Nominal angular velocity (found from RPM).
% omega0 = 120/60*2*pi;   %[rad/s] Nominal angular velocity (found from RPM).
% omega0 = 10.8;   %[rad/s] Nominal angular velocity (found from RPM).
V0 = 30/3600;           %[m/s] Nominal rate of penetration (ROP)
% omega0 = 13.0900/2-.1;
omega0 = 61.5/60*2*pi;

%% computed quantities
c_a = sqrt(E/rho);      %[m/s] Axial wave velocity 
c_t = sqrt(G/rho);      %[m/s] Torsional wave velocity
tN = 2*pi/(N*omega0);   %[s] Delay in the bit-rock interaction law
R   = V0/omega0;

zeta_ap = Ap*E/c_a;
zeta_ac = Ac*E/c_a;
zeta_tp = Jp*G/c_t;
zeta_tc = Jc*G/c_t;

t_ap = Lp/c_a;
t_ac = Lc/c_a;
t_tp = Lp/c_t;
t_tc = Lc/c_t;

eta_a = exp(-ka*(t_ap))
eta_t = exp(-kt*(t_tp));

% Nominal loop gains
Bri_a = a*zeta*epsilon*N;
Bri_t = 1/2*a^2*epsilon*N; %% %%%
Ka = Bri_a/zeta_ac;
Kt =  Bri_t /(2*zeta_tc);

% Mb_lim = Bri_a / (N*omega0^2)
Mb_lim = 8*Bri_a/ (N^2*omega0^2)
omegaS = pi*c_a/Lc/N

% Sub parameters
Mb = Ac*rho*Lc;         %[kg]
% Mb = Mb_lim * 1;      %[kg]
Ds = 3e4;           %[Ns/m]
Ks = 1e5;           %[N/m]