%% h = bodelin(H,w,opt)
%bodelin Plot Bode diagram of complex valued function (vector) H at 
%frequencies w
%
% see also: bode2
function h = bodelin(H,w,opt);

if nargin == 3 
    if isfield(opt,'hz') && opt.hz ==1
        pp = 1/2/pi;
        olab = 'Frequency (Hz)';
%         olab = 'Frequency (-)';
    else
        olab = '(rad/s)';
        pp = 1;
    end
    if isfield(opt,'linewidth')
        lw = opt.linewidth;
    else
        lw = 1;
    end
    if isfield(opt,'corphase')
        cP = opt.corphase;
    else
        cP = [];
    end
    if isfield(opt,'corphaseNEG')
        cN = opt.corphaseNEG;
    else
        cN = [];
    end
else
    olab = '(rad/s)';
    pp = 1;
    lw = 1;
    cP = [];
    cN = [];
end

subplot(211);
h = plot(w*pp,db(H),'linewidth',lw); 
hold all;
xlim([0 max(w*pp)]);
% grid on;
ylabel('Magnitude (dB)');

subplot(212);
hPhase = radtodeg(unwrap(angle(H(:,1))));
for i=1:numel(cP)
    hPhase = hPhase + 360*(w>cP(i));
end
for i=1:numel(cN)
    hPhase = hPhase - 360*(w>cN(i));
end
plot(w*pp,hPhase,'linewidth',lw)
hold all
for i=2:size(H,2)
    plot(w*pp,radtodeg(unwrap(angle(H(:,i)))),'linewidth',lw); 
end
ylabel('Phase (deg)');
xlabel(olab);
xlim([0 max(w*pp)])
% grid on;


















